Find the most commonly occuring relative expression value in each cell
Source:R/preprocessing.R
estimate_t.RdConverting relative expression values to mRNA copies per cell requires knowing the most commonly occuring relative expression value in each cell. This value typically corresponds to an RPC value of 1. This function finds the most commonly occuring (log-transformed) relative expression value for each column in the provided expression matrix.
Arguments
- relative_expr_matrix
A matrix of relative expression values for values with each row and column representing genes/isoforms and cells, respectively. Row and column names should be included. Expression values should not be log-transformed.
- relative_expr_thresh
Relative expression values below this threshold are considered zero.